@@ -63,6 +63,12 @@ def 复制文件(被复制的文件名, 复制到的文件名):
     return True
 
 
+@异常处理返回类型逻辑型
+def 复制目录(被复制的目录, 复制到的目录):
+    shutil.copytree(被复制的目录, 复制到的目录)
+    return True
+
+
 # 调用格式： 〈逻辑型〉 移动文件 （文本型 被移动的文件，文本型 移动到的位置） - 系统核心支持库->磁盘操作
 # 英文名称：FileMove
 # 将文件从一个位置移动到另外一个位置。成功返回真，失败返回假。本命令为初级命令。
@@ -159,7 +165,14 @@ def 文件_路径取扩展名(路径):
     return os.path.splitext(路径)[1]
 
 
-def 文件_取文件名(路径):
+def 文件_取文件名(路径, 是否需要拓展名=True):
+    if 是否需要拓展名:
+        return os.path.basename(路径)
+    else:
+        return os.path.splitext(os.path.basename(路径))[0]
+
+
+def 路径_取目录名(路径):
     return os.path.basename(路径)
 
 
@@ -346,7 +359,22 @@ def 文件从列表中选取存在的文件路径(路径列表):
         "/opt/model/labels.txt",
     ])
     """
-    for v in path:
+    for v in 路径列表:
         if os.path.exists(v):
             return v
-    return ''
\ No newline at end of file
+    return ''
+
+
+def 路径优化(path):
+    """
+    把\\ // 乱七八糟的路径转化为规整的
+    :param path:
+    :return:
+    """
+    if 寻找文本(path, "\\") > -1:
+        path = 子文本替换(path, "\\", "/")
+    if 寻找文本(path, r"\\") > -1:
+        path = 子文本替换(path, r"\\", "/")
+    if 寻找文本(path, r"//") > -1:
+        path = 子文本替换(path, r"//", "/")
+    return os.path.normpath(path)
