@@ -1,17 +1,31 @@
-# 系统处理
+"""
+
+.. Hint::
+    系统处理
+
+
+.. literalinclude:: ../../../pyefun/systemProcessingBase_test.py
+    :language: python
+    :caption: 代码示例
+    :linenos:
+
+"""
+
 import time
 import os
-import pyperclip
 import platform
 
+
+
 def 系统_是否为window系统():
     return platform.system().lower() == 'windows'
 
+
 def 系统_是否为linux系统():
     return platform.system().lower() == 'linux'
 
-if(系统_是否为window系统()):
-    from win32api import GetSystemMetrics
+def 系统_是否为mac系统():
+    return platform.system().lower() == 'darwin'
 
 
 # 运行
@@ -42,7 +56,6 @@ if(系统_是否为window系统()):
 # 多文件对话框
 
 
-
 def 延时(秒: int):
     time.sleep(秒)
 
@@ -54,31 +67,4 @@ def 运行(cmd):
     return x
 
 
-def 取剪辑板文本() -> str:
-    return pyperclip.paste()
 
-
-def 置剪辑板文本(str):
-    pyperclip.copy(str)
-
-
-def 剪辑板中可有文本() -> bool:
-    return 取剪辑板文本() != ""
-
-
-def 清除剪辑板():
-    pyperclip.copy("")
-
-
-def 取屏幕宽度():
-    return GetSystemMetrics(0)
-
-
-def 取屏幕高度():
-    return GetSystemMetrics(1)
-
-
-# 取鼠标水平位置
-# 取鼠标垂直位置
-def 取鼠标位置():
-    return pyautogui.position()
